@@ -1,7 +1,17 @@
+from .fileblocksink import FileBlockSink
+from .fileblocksource import FileBlockSource
+from .filecsvsink import FileCSVSink
+from .filecsvsource import FileCSVSource
+from .filejsonsource import FileJSONSource
 from .filelinesource import FileLineSource
 from .filelinesource import FileMultiLineSource
-from .fileblocksource import FileBlockSource
-from .fileblocksink import FileBlockSink
-from .filecsvsource import FileCSVSource
-from .filecsvsink import FileCSVSink
-from .filejsonsource import FileJSONSource
+
+__all__ = (
+	'FileBlockSink',
+	'FileBlockSource',
+	'FileCSVSink',
+	'FileCSVSource',
+	'FileJSONSource',
+	'FileLineSource',
+	'FileMultiLineSource',
+)
