@@ -1,8 +1,17 @@
+from .client.source import HTTPClientLineSource
 from .client.source import HTTPClientSource
 from .client.source import HTTPClientTextSource
-from .client.source import HTTPClientLineSource
 from .client.wssink import HTTPClientWebSocketSink
-
-from .web.source import WebServiceSource
 from .web.sink import WebServiceSink
+from .web.source import WebServiceSource
 from .web.wssource import WebSocketSource
+
+__all__ = (
+	'HTTPClientSource',
+	'HTTPClientTextSource',
+	'HTTPClientLineSource',
+	'HTTPClientWebSocketSink',
+	'WebServiceSource',
+	'WebServiceSink',
+	'WebSocketSource',
+)
