@@ -1,5 +1,13 @@
-from .trigger import Trigger
 from .opportunistic import OpportunisticTrigger
-from .runonce import RunOnceTrigger
-from .pubsub import PubSubTrigger
 from .periodic import PeriodicTrigger
+from .pubsub import PubSubTrigger
+from .runonce import RunOnceTrigger
+from .trigger import Trigger
+
+__all__ = (
+	'Trigger',
+	'OpportunisticTrigger',
+	'RunOnceTrigger',
+	'PubSubTrigger',
+	'PeriodicTrigger',
+)
